==> mzanalytics-0.0.9.tar.gz: ios/Classes/MzanalyticsPlugin.m <==
#import "MzanalyticsPlugin.h"
#import <MZAnalytics_BMW_1.0.2_SDK/MLTSiteSDK.h>
@implementation MzanalyticsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"mzanalytics"
            binaryMessenger:[registrar messenger]];
  MzanalyticsPlugin* instance = [[MzanalyticsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}
 

 


- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

    @try {
        
   
   if ([@"ios_appid" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
      [MLTSiteManager sharedInstanceWithAppId:call.arguments[@"appid"]  channel:@"app store"];
     
         
     }else if ([@"ios_trackPageView" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
        
         [[MLTSiteManager  shareInstance] trackPageView:call.arguments[@"pageTitle"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else   if ([@"ios_trackEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackEvent:call.arguments[@"eventClassify"] eventAction:call.arguments[@"eventAction"] eventTag:call.arguments[@"eventTag"] eventPrice:[call.arguments[@"eventPrice"] integerValue] appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"ios_trackSiteCustomEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         [[MLTSiteManager  shareInstance] trackSiteCustomEvent:call.arguments[@"CustomEvent"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"ios_trackPulse" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackPulse];
         
     } else  if ([@"ios_getCid" isEqualToString:call.method]) {
        
            
         result([MLTSiteManager getCid]);
            
        } else  if ([@"ios_setEnableLog" isEqualToString:call.method]) {
            result([NSNumber numberWithBool:YES]);

            [MLTSiteManager setEnableLog:call.arguments[@"Enable"]];
               
           }  else  if ([@"ios_handleOpenURL" isEqualToString:call.method]) {
                  result([NSNumber numberWithBool:YES]);
                     
                     
                  [MLTSiteManager  handleOpenURL:call.arguments[@"url"]];
                     
                 }   else {
    result(FlutterMethodNotImplemented);
  }
    } @catch (NSException *exception) {
        
    } @finally {
        
    }
}

@end

==> mzanalytics-0.2.14.tar.gz: ios/Classes/MzanalyticsPlugin.m <==
#import "MzanalyticsPlugin.h"
#import <MZAnalytics_BMW_1.0.2_SDK/MLTSiteSDK.h>
@implementation MzanalyticsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"mzanalytics"
            binaryMessenger:[registrar messenger]];
  MzanalyticsPlugin* instance = [[MzanalyticsPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}
 

 


- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {

    @try {
        
   
   if ([@"ios_appid" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
      [MLTSiteManager sharedInstanceWithAppId:call.arguments[@"appid"]  channel:@"app store"];
     
         
     }else if ([@"ios_trackPageView" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
        
         [[MLTSiteManager  shareInstance] trackPageView:call.arguments[@"pageTitle"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else   if ([@"ios_trackEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackEvent:call.arguments[@"eventClassify"] eventAction:call.arguments[@"eventAction"] eventTag:call.arguments[@"eventTag"] eventPrice:call.arguments[@"eventPrice"] appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"ios_trackSiteCustomEvent" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         [[MLTSiteManager  shareInstance] trackSiteCustomEvent:call.arguments[@"CustomEvent"]  appendCustomDimMetrics:[call.arguments objectForKey:@"CustomDimMetrics"]?[call.arguments objectForKey:@"CustomDimMetrics"]:nil];
         
     } else  if ([@"ios_trackPulse" isEqualToString:call.method]) {
      result([NSNumber numberWithBool:YES]);
         
         
         
      [[MLTSiteManager  shareInstance] trackPulse];
         
     } else  if ([@"ios_getCid" isEqualToString:call.method]) {
        
            
         result([MLTSiteManager getCid]);
            
        } else  if ([@"ios_setEnableLog" isEqualToString:call.method]) {
            result([NSNumber numberWithBool:YES]);

            [MLTSiteManager setEnableLog:call.arguments[@"Enable"]];
               
           }  else  if ([@"ios_handleOpenURL" isEqualToString:call.method]) {
                  result([NSNumber numberWithBool:YES]);
                     
                     
                  [MLTSiteManager  handleOpenURL:call.arguments[@"url"]];
                     
                 }   else {
    result(FlutterMethodNotImplemented);
  }
    } @catch (NSException *exception) {
        
    } @finally {
        
    }
}

@end
